#include <Wire.h>
#include <SPI.h>
#include <Adafruit_Sensor.h>
#include "Adafruit_BME680.h"
#include <SFE_MicroOLED.h> // Include the SFE_MicroOLED library

#define PIN_RESET 255 //
#define DC_JUMPER 0 // I2C Addres: 0 - 0x3C, 1 - 0x3D
#define SEALEVELPRESSURE_HPA (1013.25)

MicroOLED oled(PIN_RESET, DC_JUMPER); // Example I2C declaration
Adafruit_BME680 bme; // I2C

void setup() {
  Serial.begin(9600);
  while (!Serial);
  Serial.println(F("BME680 test"));

  if (!bme.begin(0x76)) 
  {
    Serial.println("Could not find a valid BME680 sensor, check wiring!");
    while (1);
  }

  // Set up oversampling and filter initialization
  bme.setTemperatureOversampling(BME680_OS_8X);
  bme.setHumidityOversampling(BME680_OS_2X);
  bme.setPressureOversampling(BME680_OS_4X);
  bme.setIIRFilterSize(BME680_FILTER_SIZE_3);
  bme.setGasHeater(320, 150); // 320*C for 150 ms
  //start the OLED
  oled.begin();
  oled.clear(ALL); // Clear the display's memory (gets rid of artifacts)
  oled.display();
}

void loop() 
{
  if (! bme.performReading()) 
  {
    Serial.println("Failed to perform reading :(");
    return;
  }
  oled.clear(PAGE);
  oled.setFontType(0); // set font type 0, please see declaration in SFE_MicroOLED.cpp
  oled.setCursor(1, 3);
  oled.print("Humidity = ");
  oled.setCursor(1, 12);
  oled.print(bme.humidity);
  oled.print(" %");
  oled.setCursor(1, 21);
  oled.print("Temp =");
  oled.setCursor(1, 30);
  oled.print(bme.temperature);
  oled.print(" *C ");
  oled.display();
  delay(2000);
  //2nd page of readings
  oled.clear(PAGE);
  oled.setFontType(0); // set font type 0, please see declaration in SFE_MicroOLED.cpp
  oled.setCursor(1, 3);
  oled.print("Altitude = ");
  oled.setCursor(1, 12);
  oled.print(bme.readAltitude(SEALEVELPRESSURE_HPA));
  oled.print(" m");
  oled.setCursor(1, 21);
  oled.print("Sea Level=");
  oled.setCursor(1, 30);
  oled.print(bme.pressure / 100.0);
  oled.print(" hPa");
  oled.display();
  delay(2000);
  //3rd page of readings
  oled.clear(PAGE);
  oled.setFontType(0); // set font type 0, please see declaration in SFE_MicroOLED.cpp
  oled.setCursor(1, 3);
  oled.print("Gas = ");
  oled.setCursor(1, 12);
  oled.print(bme.gas_resistance / 1000.0);
  oled.println(" KOhms");
  oled.display();
  delay(2000);
}
